WalletWeb3Provider class

Constructors

WalletWeb3Provider({required String address, required int? chainId, required String? rpcUrl})

Properties

address String
getter/setter pair
chainId int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rpcUrl String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited